==> libreoffice_4.3.3.orig.tar.xz: libreoffice-4.3.3.2/sd/source/ui/sidebar/SlideTransitionPanel.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "SlideTransitionPanel.hxx"
#include "createslidetransitionpanel.hxx"

#include "ViewShellBase.hxx"

namespace sd { namespace sidebar {


SlideTransitionPanel::SlideTransitionPanel (
    ::Window* pParentWindow,
    ViewShellBase& rViewShellBase,
    const cssu::Reference<css::frame::XFrame>& rxFrame
    )
    : PanelBase(pParentWindow, rViewShellBase),
      mxFrame( rxFrame )
{
#ifdef DEBUG
    SetText(OUString("sd:SlideTransitionPanel"));
#endif
}




SlideTransitionPanel::~SlideTransitionPanel (void)
{
}




::Window* SlideTransitionPanel::CreateWrappedControl (
    ::Window* pParentWindow,
    ViewShellBase& rViewShellBase)
{
    return createSlideTransitionPanel(pParentWindow, rViewShellBase, mxFrame);
}




css::ui::LayoutSize SlideTransitionPanel::GetHeightForWidth (const sal_Int32 /*nWidth*/)
{
    Window *pControl = mpWrappedControl.get();
    sal_Int32 nMinimumHeight = pControl ? pControl->get_preferred_size().Height() : 0;
    return css::ui::LayoutSize(nMinimumHeight,-1, nMinimumHeight);
}

} } // end of namespace sd::sidebar

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-5.4.1.2.tar.xz: libreoffice-5.4.1.2/sd/source/ui/sidebar/SlideTransitionPanel.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "SlideTransitionPanel.hxx"
#include "createslidetransitionpanel.hxx"

#include "ViewShellBase.hxx"

namespace sd { namespace sidebar {

SlideTransitionPanel::SlideTransitionPanel (
    vcl::Window* pParentWindow,
    ViewShellBase& rViewShellBase,
    const css::uno::Reference<css::frame::XFrame>& rxFrame
    )
    : PanelBase(pParentWindow, rViewShellBase),
      mxFrame( rxFrame )
{
#ifdef DEBUG
    SetText(OUString("sd:SlideTransitionPanel"));
#endif
}

SlideTransitionPanel::~SlideTransitionPanel()
{
}

vcl::Window* SlideTransitionPanel::CreateWrappedControl (
    vcl::Window* pParentWindow,
    ViewShellBase& rViewShellBase)
{
    return createSlideTransitionPanel(pParentWindow, rViewShellBase, mxFrame);
}

css::ui::LayoutSize SlideTransitionPanel::GetHeightForWidth (const sal_Int32 /*nWidth*/)
{
    vcl::Window *pControl = mpWrappedControl.get();
    sal_Int32 nMinimumHeight = pControl ? pControl->get_preferred_size().Height() : 0;
    return css::ui::LayoutSize(nMinimumHeight,-1, nMinimumHeight);
}

} } // end of namespace sd::sidebar

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
